Interface: ChartComponent | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ChartComponent

## # Hierarchy

- `ChartComponent`

  ↳ `DatasetControllerChartComponent`

## # Properties

### # defaultRoutes

• `Optional` defaultRoutes: `Object`

#### # Index signature

▪ [property: `string`]: `string`

#### # Defined in

index.esm.d.ts:1414
(opens new window)

### # defaults

• `Optional` defaults: `AnyObject`

#### # Defined in

index.esm.d.ts:1413
(opens new window)

### # id

• id: `string`

#### # Defined in

index.esm.d.ts:1412
(opens new window)

## # Methods

### # afterRegister

▸ `Optional` afterRegister(): `void`

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1417
(opens new window)

### # afterUnregister

▸ `Optional` afterUnregister(): `void`

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1419
(opens new window)

### # beforeRegister

▸ `Optional` beforeRegister(): `void`

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1416
(opens new window)

### # beforeUnregister

▸ `Optional` beforeUnregister(): `void`

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1418
(opens new window)